summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2023-11-16 15:37:49 (GMT)
committerBrad King <brad.king@kitware.com>2023-11-17 14:58:21 (GMT)
commit2744f14db1e87f4b7f6eb6f30f7c84ea52ce4a7a (patch)
tree35ee84cee04924eb7112971ebff1e5b80d818b90
parentf2776ac063e45fea91e4d496a910a0a6d10ed064 (diff)
downloadCMake-2744f14db1e87f4b7f6eb6f30f7c84ea52ce4a7a.zip
CMake-2744f14db1e87f4b7f6eb6f30f7c84ea52ce4a7a.tar.gz
CMake-2744f14db1e87f4b7f6eb6f30f7c84ea52ce4a7a.tar.bz2
codespell: Fix typos
-rw-r--r--CMakeCPackOptions.cmake.in2
-rw-r--r--Help/command/cmake_language.rst2
-rw-r--r--Help/command/target_precompile_headers.rst2
-rw-r--r--Help/cpack_gen/freebsd.rst4
-rw-r--r--Help/dev/maint.rst2
-rw-r--r--Help/release/3.21.rst2
-rw-r--r--Help/variable/CMAKE_FIND_PACKAGE_REDIRECTS_DIR.rst2
-rw-r--r--Modules/CheckCCompilerFlag.cmake2
-rw-r--r--Modules/CheckCSourceCompiles.cmake2
-rw-r--r--Modules/CheckCSourceRuns.cmake2
-rw-r--r--Modules/CheckCXXSourceCompiles.cmake2
-rw-r--r--Modules/CheckCXXSourceRuns.cmake2
-rw-r--r--Modules/CheckCompilerFlag.cmake2
-rw-r--r--Modules/CheckFortranCompilerFlag.cmake2
-rw-r--r--Modules/CheckFortranSourceCompiles.cmake2
-rw-r--r--Modules/CheckFortranSourceRuns.cmake2
-rw-r--r--Modules/CheckOBJCCompilerFlag.cmake2
-rw-r--r--Modules/CheckOBJCSourceCompiles.cmake2
-rw-r--r--Modules/CheckOBJCSourceRuns.cmake2
-rw-r--r--Modules/CheckOBJCXXCompilerFlag.cmake2
-rw-r--r--Modules/CheckOBJCXXSourceCompiles.cmake2
-rw-r--r--Modules/CheckOBJCXXSourceRuns.cmake2
-rw-r--r--Modules/CheckSourceCompiles.cmake2
-rw-r--r--Modules/CheckSourceRuns.cmake2
-rw-r--r--Modules/Compiler/GNU-CXX-FeatureTests.cmake2
-rw-r--r--Modules/Compiler/LCC-CXX-FeatureTests.cmake2
-rw-r--r--Modules/ExternalProject.cmake4
-rw-r--r--Modules/FindCUDA.cmake2
-rw-r--r--Modules/FindEnvModules.cmake2
-rw-r--r--Modules/FindMPI.cmake2
-rw-r--r--Modules/FindSDL.cmake2
-rw-r--r--Modules/FindSDL_sound.cmake2
-rw-r--r--Modules/FindXCTest.cmake2
-rw-r--r--Modules/Internal/CPack/CPackFreeBSD.cmake2
-rw-r--r--Modules/UseJava.cmake2
-rw-r--r--Source/Modules/CMakeBuildUtilities.cmake4
-rw-r--r--Source/cmCPluginAPI.cxx4
-rw-r--r--Source/cmComputeLinkDepends.cxx4
-rw-r--r--Source/cmComputeLinkInformation.cxx2
-rw-r--r--Source/cmExtraCodeLiteGenerator.cxx2
-rw-r--r--Source/cmFileTimes.cxx2
-rw-r--r--Source/cmGeneratorTarget.cxx8
-rw-r--r--Source/cmGlobalGenerator.cxx4
-rw-r--r--Source/cmMakefile.cxx2
-rw-r--r--Tests/CPackComponentsDEB/RunCPackVerifyResult.cmake2
-rw-r--r--Tests/CPackComponentsForAll/RunCPackVerifyResult.cmake2
-rw-r--r--Tests/CTestUpdateCVS.cmake.in2
-rw-r--r--Tests/RunCMake/ctest_memcheck/testAddressSanitizer.cmake2
-rw-r--r--Tests/RunCMake/ctest_memcheck/testMemorySanitizer.cmake2
-rw-r--r--Tests/RunCMake/ctest_memcheck/testThreadSanitizer.cmake2
-rw-r--r--Tests/RunCMake/ctest_memcheck/testUndefinedBehaviorSanitizer.cmake2
-rw-r--r--Tests/UseSWIG/ModuleVersion2/CMakeLists.txt4
-rw-r--r--Tests/UseSWIG/MultipleModules/CMakeLists.txt2
-rw-r--r--Tests/UseSWIG/MultiplePython/CMakeLists.txt2
54 files changed, 64 insertions, 64 deletions
diff --git a/CMakeCPackOptions.cmake.in b/CMakeCPackOptions.cmake.in
index f354362..7aacf8e 100644
--- a/CMakeCPackOptions.cmake.in
+++ b/CMakeCPackOptions.cmake.in
@@ -5,7 +5,7 @@
if(CPACK_GENERATOR MATCHES "NSIS")
set(CPACK_NSIS_INSTALL_ROOT "@CPACK_NSIS_INSTALL_ROOT@")
- # set the install/unistall icon used for the installer itself
+ # set the install/uninstall icon used for the installer itself
# There is a bug in NSI that does not handle full unix paths properly.
set(CPACK_NSIS_MUI_ICON "@CMake_SOURCE_DIR@/Utilities/Release\\CMakeLogo.ico")
set(CPACK_NSIS_MUI_UNIICON "@CMake_SOURCE_DIR@/Utilities/Release\\CMakeLogo.ico")
diff --git a/Help/command/cmake_language.rst b/Help/command/cmake_language.rst
index 707568c..3af6b9c 100644
--- a/Help/command/cmake_language.rst
+++ b/Help/command/cmake_language.rst
@@ -195,7 +195,7 @@ prints::
Immediate Message
Deferred Message
-The ``Cancelled Message`` is never printed because its command is
+The ``Canceled Message`` is never printed because its command is
canceled. The ``deferred_message`` variable reference is not evaluated
until the call site, so it can be set after the deferred call is scheduled.
diff --git a/Help/command/target_precompile_headers.rst b/Help/command/target_precompile_headers.rst
index db55bc2..50eaf22 100644
--- a/Help/command/target_precompile_headers.rst
+++ b/Help/command/target_precompile_headers.rst
@@ -94,7 +94,7 @@ Reusing Precompile Headers
^^^^^^^^^^^^^^^^^^^^^^^^^^
The command also supports a second signature which can be used to specify that
-one target re-uses a precompiled header file artifact from another target
+one target reuses a precompiled header file artifact from another target
instead of generating its own:
.. code-block:: cmake
diff --git a/Help/cpack_gen/freebsd.rst b/Help/cpack_gen/freebsd.rst
index e97ba49..2a4a308 100644
--- a/Help/cpack_gen/freebsd.rst
+++ b/Help/cpack_gen/freebsd.rst
@@ -19,9 +19,9 @@ be used on FreeBSD, DragonflyBSD, NetBSD, OpenBSD, but also on Linux or OSX,
depending on the installed package-management tools -- using :module:`CPack`.
The CPack FreeBSD generator is a :module:`CPack` generator and uses the
-:variable:`!CPACK_XXX` variables used by :module:`CPack`. It tries to re-use packaging
+:variable:`!CPACK_XXX` variables used by :module:`CPack`. It tries to reuse packaging
information that may already be specified for Debian packages for the
-:cpack_gen:`CPack DEB Generator`. It also tries to re-use RPM packaging
+:cpack_gen:`CPack DEB Generator`. It also tries to reuse RPM packaging
information when Debian does not specify.
The CPack FreeBSD generator should work on any host with libpkg installed. The
diff --git a/Help/dev/maint.rst b/Help/dev/maint.rst
index de19aa8..81e0e6f 100644
--- a/Help/dev/maint.rst
+++ b/Help/dev/maint.rst
@@ -338,7 +338,7 @@ policies added for that version. Commit with a message such as::
export: Increase maximum policy version in exported files to $prev
- The files generatd by `install(EXPORT)` and `export()` commands
+ The files generated by `install(EXPORT)` and `export()` commands
are known to work with policies as of CMake $prev, so enable them
in sufficiently new CMake versions.
diff --git a/Help/release/3.21.rst b/Help/release/3.21.rst
index 91c3768..8da1c94 100644
--- a/Help/release/3.21.rst
+++ b/Help/release/3.21.rst
@@ -318,7 +318,7 @@ Changes made since CMake 3.21.0 include the following.
* The :generator:`Visual Studio 17 2022` generator is now based on
"Visual Studio 2022 Preview 4". Previously it was based on "Preview 3.1".
-* The AMD ROCm Platform ``hipcc`` compiler was identifed by CMake 3.21.0
+* The AMD ROCm Platform ``hipcc`` compiler was identified by CMake 3.21.0
through 3.21.2 as a distinct compiler with id ``ROCMClang``. This has
been removed because it caused regressions. Instead:
diff --git a/Help/variable/CMAKE_FIND_PACKAGE_REDIRECTS_DIR.rst b/Help/variable/CMAKE_FIND_PACKAGE_REDIRECTS_DIR.rst
index b27a3d9..73bef87 100644
--- a/Help/variable/CMAKE_FIND_PACKAGE_REDIRECTS_DIR.rst
+++ b/Help/variable/CMAKE_FIND_PACKAGE_REDIRECTS_DIR.rst
@@ -12,7 +12,7 @@ The primary purpose of this variable is to facilitate integration between
:command:`find_package` and :command:`FetchContent_MakeAvailable`. The latter
command may create files in the ``CMAKE_FIND_PACKAGE_REDIRECTS_DIR`` directory
when it populates a dependency. This allows subsequent calls to
-:command:`find_package` for the same dependency to re-use the populated
+:command:`find_package` for the same dependency to reuse the populated
contents instead of trying to satisfy the dependency from somewhere external
to the build. Projects may also want to write files into this directory in
some situations (see :ref:`FetchContent-find_package-integration-examples`
diff --git a/Modules/CheckCCompilerFlag.cmake b/Modules/CheckCCompilerFlag.cmake
index 12b0976..27b7ae8 100644
--- a/Modules/CheckCCompilerFlag.cmake
+++ b/Modules/CheckCCompilerFlag.cmake
@@ -22,7 +22,7 @@ issue a diagnostic message when given the flag. Whether the flag has any
effect or even a specific one is beyond the scope of this module.
The check is only performed once, with the result cached in the variable named
-by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckCSourceCompiles.cmake b/Modules/CheckCSourceCompiles.cmake
index ce4719a..79aca93 100644
--- a/Modules/CheckCSourceCompiles.cmake
+++ b/Modules/CheckCSourceCompiles.cmake
@@ -23,7 +23,7 @@ Check if given C source compiles and links into an executable.
expressions.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckCSourceRuns.cmake b/Modules/CheckCSourceRuns.cmake
index d5a8fda..e06bcca 100644
--- a/Modules/CheckCSourceRuns.cmake
+++ b/Modules/CheckCSourceRuns.cmake
@@ -22,7 +22,7 @@ subsequently be run.
false (e.g. an empty string or an error message).
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckCXXSourceCompiles.cmake b/Modules/CheckCXXSourceCompiles.cmake
index 4b33aa8..7531236 100644
--- a/Modules/CheckCXXSourceCompiles.cmake
+++ b/Modules/CheckCXXSourceCompiles.cmake
@@ -23,7 +23,7 @@ Check if given C++ source compiles and links into an executable.
expressions.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckCXXSourceRuns.cmake b/Modules/CheckCXXSourceRuns.cmake
index 3402715..eb643eb 100644
--- a/Modules/CheckCXXSourceRuns.cmake
+++ b/Modules/CheckCXXSourceRuns.cmake
@@ -22,7 +22,7 @@ subsequently be run.
false (e.g. an empty string or an error message).
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckCompilerFlag.cmake b/Modules/CheckCompilerFlag.cmake
index a18435b..0f2ec4c 100644
--- a/Modules/CheckCompilerFlag.cmake
+++ b/Modules/CheckCompilerFlag.cmake
@@ -23,7 +23,7 @@ issue a diagnostic message when given the flag. Whether the flag has any
effect or even a specific one is beyond the scope of this module.
The check is only performed once, with the result cached in the variable named
-by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckFortranCompilerFlag.cmake b/Modules/CheckFortranCompilerFlag.cmake
index 9164565..81a2345 100644
--- a/Modules/CheckFortranCompilerFlag.cmake
+++ b/Modules/CheckFortranCompilerFlag.cmake
@@ -24,7 +24,7 @@ issue a diagnostic message when given the flag. Whether the flag has any
effect or even a specific one is beyond the scope of this module.
The check is only performed once, with the result cached in the variable named
-by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckFortranSourceCompiles.cmake b/Modules/CheckFortranSourceCompiles.cmake
index 5158b7e..ed374ef 100644
--- a/Modules/CheckFortranSourceCompiles.cmake
+++ b/Modules/CheckFortranSourceCompiles.cmake
@@ -48,7 +48,7 @@ Check if given Fortran source compiles and links into an executable.
``.F90`` is a typical choice.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckFortranSourceRuns.cmake b/Modules/CheckFortranSourceRuns.cmake
index f996749..9bf9fb2 100644
--- a/Modules/CheckFortranSourceRuns.cmake
+++ b/Modules/CheckFortranSourceRuns.cmake
@@ -44,7 +44,7 @@ subsequently be run.
``SRC_EXT`` option can be used to override this with ``.<extension>`` instead.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCCompilerFlag.cmake b/Modules/CheckOBJCCompilerFlag.cmake
index 24bf0db..f6d259e 100644
--- a/Modules/CheckOBJCCompilerFlag.cmake
+++ b/Modules/CheckOBJCCompilerFlag.cmake
@@ -24,7 +24,7 @@ issue a diagnostic message when given the flag. Whether the flag has any
effect or even a specific one is beyond the scope of this module.
The check is only performed once, with the result cached in the variable named
-by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCSourceCompiles.cmake b/Modules/CheckOBJCSourceCompiles.cmake
index 7663054..bc0cac1 100644
--- a/Modules/CheckOBJCSourceCompiles.cmake
+++ b/Modules/CheckOBJCSourceCompiles.cmake
@@ -25,7 +25,7 @@ Check if given Objective-C source compiles and links into an executable.
expressions.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCSourceRuns.cmake b/Modules/CheckOBJCSourceRuns.cmake
index a23a0c7..511cac6 100644
--- a/Modules/CheckOBJCSourceRuns.cmake
+++ b/Modules/CheckOBJCSourceRuns.cmake
@@ -24,7 +24,7 @@ subsequently be run.
false (e.g. an empty string or an error message).
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCXXCompilerFlag.cmake b/Modules/CheckOBJCXXCompilerFlag.cmake
index ae2d907..32d50c9 100644
--- a/Modules/CheckOBJCXXCompilerFlag.cmake
+++ b/Modules/CheckOBJCXXCompilerFlag.cmake
@@ -24,7 +24,7 @@ issue a diagnostic message when given the flag. Whether the flag has any
effect or even a specific one is beyond the scope of this module.
The check is only performed once, with the result cached in the variable named
-by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCXXSourceCompiles.cmake b/Modules/CheckOBJCXXSourceCompiles.cmake
index cfbda3a..366d7d5 100644
--- a/Modules/CheckOBJCXXSourceCompiles.cmake
+++ b/Modules/CheckOBJCXXSourceCompiles.cmake
@@ -25,7 +25,7 @@ Check if given Objective-C++ source compiles and links into an executable.
expressions.
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckOBJCXXSourceRuns.cmake b/Modules/CheckOBJCXXSourceRuns.cmake
index b2831b6..49db3cb 100644
--- a/Modules/CheckOBJCXXSourceRuns.cmake
+++ b/Modules/CheckOBJCXXSourceRuns.cmake
@@ -24,7 +24,7 @@ subsequently be run.
false (e.g. an empty string or an error message).
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckSourceCompiles.cmake b/Modules/CheckSourceCompiles.cmake
index 041b59c..af905a4 100644
--- a/Modules/CheckSourceCompiles.cmake
+++ b/Modules/CheckSourceCompiles.cmake
@@ -48,7 +48,7 @@ Check if given source compiles and links into an executable.
HAVE_ERROR_STOP)
The check is only performed once, with the result cached in the variable
- named by ``<resultVar>``. Every subsequent CMake run will re-use this cached
+ named by ``<resultVar>``. Every subsequent CMake run will reuse this cached
value rather than performing the check again, even if the ``<code>`` changes.
In order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/CheckSourceRuns.cmake b/Modules/CheckSourceRuns.cmake
index 822ee07..75636f4 100644
--- a/Modules/CheckSourceRuns.cmake
+++ b/Modules/CheckSourceRuns.cmake
@@ -48,7 +48,7 @@ subsequently be run.
HAVE_COARRAY)
The check is only performed once, with the result cached in the variable named
- by ``<resultVar>``. Every subsequent CMake run will re-use this cached value
+ by ``<resultVar>``. Every subsequent CMake run will reuse this cached value
rather than performing the check again, even if the ``<code>`` changes. In
order to force the check to be re-evaluated, the variable named by
``<resultVar>`` must be manually removed from the cache.
diff --git a/Modules/Compiler/GNU-CXX-FeatureTests.cmake b/Modules/Compiler/GNU-CXX-FeatureTests.cmake
index 45c5470..a9663d6 100644
--- a/Modules/Compiler/GNU-CXX-FeatureTests.cmake
+++ b/Modules/Compiler/GNU-CXX-FeatureTests.cmake
@@ -54,7 +54,7 @@ set(_cmake_feature_test_cxx_user_literals "${GNU47_CXX11}")
# NOTE: C++11 was ratified in September 2011. GNU 4.7 is the first minor
# release following that (March 2012), and the first minor release to
# support -std=c++11. Prior to that, support for C++11 features is technically
-# experiemental and possibly incomplete (see for example the note below about
+# experimental and possibly incomplete (see for example the note below about
# cxx_variadic_template_template_parameters)
# GNU does not define __cplusplus correctly before version 4.7.
# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=1773
diff --git a/Modules/Compiler/LCC-CXX-FeatureTests.cmake b/Modules/Compiler/LCC-CXX-FeatureTests.cmake
index 45c5470..a9663d6 100644
--- a/Modules/Compiler/LCC-CXX-FeatureTests.cmake
+++ b/Modules/Compiler/LCC-CXX-FeatureTests.cmake
@@ -54,7 +54,7 @@ set(_cmake_feature_test_cxx_user_literals "${GNU47_CXX11}")
# NOTE: C++11 was ratified in September 2011. GNU 4.7 is the first minor
# release following that (March 2012), and the first minor release to
# support -std=c++11. Prior to that, support for C++11 features is technically
-# experiemental and possibly incomplete (see for example the note below about
+# experimental and possibly incomplete (see for example the note below about
# cxx_variadic_template_template_parameters)
# GNU does not define __cplusplus correctly before version 4.7.
# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=1773
diff --git a/Modules/ExternalProject.cmake b/Modules/ExternalProject.cmake
index f43f48d..3ec0557 100644
--- a/Modules/ExternalProject.cmake
+++ b/Modules/ExternalProject.cmake
@@ -522,7 +522,7 @@ overridden if required.
use the same generator as the main project, but the ``CMAKE_GENERATOR``
option can be given to override this. The project is responsible for
adding any toolchain details, flags or other settings it wants to
- re-use from the main project or otherwise specify (see ``CMAKE_ARGS``,
+ reuse from the main project or otherwise specify (see ``CMAKE_ARGS``,
``CMAKE_CACHE_ARGS`` and ``CMAKE_CACHE_DEFAULT_ARGS`` below).
For non-CMake external projects, the ``CONFIGURE_COMMAND`` option must
@@ -593,7 +593,7 @@ overridden if required.
as initial defaults only and will not override any variables already set
from a previous run. Use this option with care, as it can lead to
different behavior depending on whether the build starts from a fresh
- build directory or re-uses previous build contents.
+ build directory or reuses previous build contents.
.. versionadded:: 3.15
If the CMake generator is the ``Green Hills MULTI`` and not overridden,
diff --git a/Modules/FindCUDA.cmake b/Modules/FindCUDA.cmake
index 0d7f1a4..203a473 100644
--- a/Modules/FindCUDA.cmake
+++ b/Modules/FindCUDA.cmake
@@ -1423,7 +1423,7 @@ function(CUDA_COMPUTE_BUILD_PATH path build_path)
# Only deal with CMake style paths from here on out
file(TO_CMAKE_PATH "${path}" bpath)
if (IS_ABSOLUTE "${bpath}")
- # Absolute paths are generally unnessary, especially if something like
+ # Absolute paths are generally unnecessary, especially if something like
# file(GLOB_RECURSE) is used to pick up the files.
string(FIND "${bpath}" "${CMAKE_CURRENT_BINARY_DIR}" _binary_dir_pos)
diff --git a/Modules/FindEnvModules.cmake b/Modules/FindEnvModules.cmake
index dab97ac..5337e4f 100644
--- a/Modules/FindEnvModules.cmake
+++ b/Modules/FindEnvModules.cmake
@@ -81,7 +81,7 @@ modules:
.. command:: env_module
- Execute an aribitrary module command:
+ Execute an arbitrary module command:
.. code-block:: cmake
diff --git a/Modules/FindMPI.cmake b/Modules/FindMPI.cmake
index e3246c6..a25f113 100644
--- a/Modules/FindMPI.cmake
+++ b/Modules/FindMPI.cmake
@@ -436,7 +436,7 @@ function (_MPI_interrogate_compiler LANG)
# a particular MPICH derivate might check compiler interoperability.
# Intel MPI in particular does this with I_MPI_CHECK_COMPILER.
file(TO_NATIVE_PATH "${CMAKE_${LANG}_COMPILER}" _MPI_UNDERLAYING_COMPILER)
- # On Windows, the Intel MPI batch scripts can only work with filnames - Full paths will break them.
+ # On Windows, the Intel MPI batch scripts can only work with filenames - Full paths will break them.
# Due to the lack of other MPICH-based wrappers for Visual C++, we may treat this as default.
if(MSVC)
get_filename_component(_MPI_UNDERLAYING_COMPILER "${_MPI_UNDERLAYING_COMPILER}" NAME)
diff --git a/Modules/FindSDL.cmake b/Modules/FindSDL.cmake
index c68e18d..7691eb7 100644
--- a/Modules/FindSDL.cmake
+++ b/Modules/FindSDL.cmake
@@ -181,7 +181,7 @@ if(SDL_LIBRARY_TEMP)
# For OS X, SDL uses Cocoa as a backend so it must link to Cocoa.
# CMake doesn't display the -framework Cocoa string in the UI even
- # though it actually is there if I modify a pre-used variable.
+ # though it actually is there if I modify a preused variable.
# I think it has something to do with the CACHE STRING.
# So I use a temporary variable until the end so I can set the
# "real" variable in one-shot.
diff --git a/Modules/FindSDL_sound.cmake b/Modules/FindSDL_sound.cmake
index d863e3c..3443959 100644
--- a/Modules/FindSDL_sound.cmake
+++ b/Modules/FindSDL_sound.cmake
@@ -196,7 +196,7 @@ if(SDL_FOUND AND SDL_SOUND_INCLUDE_DIR AND SDL_SOUND_LIBRARY)
# I expect that MPGLIB, VOC, WAV, AIFF, and SHN are compiled in statically.
# I think Timidity is also compiled in statically.
- # I've never had to explcitly link against Quicktime, so I'll skip that for now.
+ # I've never had to explicitly link against Quicktime, so I'll skip that for now.
set(SDL_SOUND_LIBRARIES_TMP ${SDL_SOUND_LIBRARY})
diff --git a/Modules/FindXCTest.cmake b/Modules/FindXCTest.cmake
index 40e767b..a01c010 100644
--- a/Modules/FindXCTest.cmake
+++ b/Modules/FindXCTest.cmake
@@ -74,7 +74,7 @@ if(CMAKE_EFFECTIVE_SYSTEM_NAME STREQUAL "Apple"
# platform directory which is not added to the CMAKE_FIND_ROOT_PATH
# (only to CMAKE_SYSTEM_FRAMEWORK_PATH) and therefore not searched.
#
- # Until this is properly addressed, temporaily add the platform
+ # Until this is properly addressed, temporarily add the platform
# directory to CMAKE_FIND_ROOT_PATH.
list(APPEND CMAKE_FIND_ROOT_PATH "${_CMAKE_OSX_SYSROOT_PATH}/../..")
endif()
diff --git a/Modules/Internal/CPack/CPackFreeBSD.cmake b/Modules/Internal/CPack/CPackFreeBSD.cmake
index c35089c..46a7bf7 100644
--- a/Modules/Internal/CPack/CPackFreeBSD.cmake
+++ b/Modules/Internal/CPack/CPackFreeBSD.cmake
@@ -66,7 +66,7 @@ _cpack_freebsd_fallback_var("CPACK_FREEBSD_PACKAGE_DESCRIPTION"
)
# There's really only one homepage for a project, so
-# re-use the Debian setting if it's there.
+# reuse the Debian setting if it's there.
_cpack_freebsd_fallback_var("CPACK_FREEBSD_PACKAGE_WWW"
"CPACK_PACKAGE_HOMEPAGE_URL"
"CPACK_DEBIAN_PACKAGE_HOMEPAGE"
diff --git a/Modules/UseJava.cmake b/Modules/UseJava.cmake
index 99fd617..1724c3a 100644
--- a/Modules/UseJava.cmake
+++ b/Modules/UseJava.cmake
@@ -1521,7 +1521,7 @@ function (create_javah)
"CLASSES;CLASSPATH;DEPENDS"
${ARGN})
- # ckeck parameters
+ # check parameters
if (NOT _create_javah_TARGET AND NOT _create_javah_GENERATED_FILES)
message (FATAL_ERROR "create_javah: TARGET or GENERATED_FILES must be specified.")
endif()
diff --git a/Source/Modules/CMakeBuildUtilities.cmake b/Source/Modules/CMakeBuildUtilities.cmake
index c891fe9..21f04e6 100644
--- a/Source/Modules/CMakeBuildUtilities.cmake
+++ b/Source/Modules/CMakeBuildUtilities.cmake
@@ -4,7 +4,7 @@
# Originally it was a macro in the root `CMakeLists.txt` with the comment
# "Simply to improve readability...".
# However, as part of the modernization refactoring it was moved into a
-# separate file cuz adding library alises wasn't possible inside the
+# separate file cuz adding library aliases wasn't possible inside the
# macro.
#-----------------------------------------------------------------------
@@ -170,7 +170,7 @@ else()
CMAKE_SET_TARGET_FOLDER(cmcurl "Utilities/3rdParty")
CMAKE_SET_TARGET_FOLDER(LIBCURL "Utilities/3rdParty")
if(NOT CMAKE_USE_SYSTEM_NGHTTP2)
- # Configure after curl to re-use some check results.
+ # Configure after curl to reuse some check results.
add_subdirectory(Utilities/cmnghttp2)
CMAKE_SET_TARGET_FOLDER(cmnghttp2 "Utilities/3rdParty")
endif()
diff --git a/Source/cmCPluginAPI.cxx b/Source/cmCPluginAPI.cxx
index 655f4bc..2e6cd40 100644
--- a/Source/cmCPluginAPI.cxx
+++ b/Source/cmCPluginAPI.cxx
@@ -549,7 +549,7 @@ static void CCONV* cmGetSource(void* arg, const char* name)
sf->SourceExtension =
cmSystemTools::GetFilenameLastExtension(sf->FullPath);
- // Store the proxy in the map so it can be re-used and deleted later.
+ // Store the proxy in the map so it can be reused and deleted later.
i = cmCPluginAPISourceFiles.emplace(rsf, std::move(sf)).first;
}
return i->second.get();
@@ -584,7 +584,7 @@ static void* CCONV cmAddSource(void* arg, void* arg2)
sf->SourceName = osf->SourceName;
sf->SourceExtension = osf->SourceExtension;
- // Store the proxy in the map so it can be re-used and deleted later.
+ // Store the proxy in the map so it can be reused and deleted later.
auto* value = sf.get();
cmCPluginAPISourceFiles[rsf] = std::move(sf);
return value;
diff --git a/Source/cmComputeLinkInformation.cxx b/Source/cmComputeLinkInformation.cxx
index f54f550..297ae1d 100644
--- a/Source/cmComputeLinkInformation.cxx
+++ b/Source/cmComputeLinkInformation.cxx
@@ -2591,7 +2591,7 @@ std::string cmComputeLinkInformation::GetRPathString(bool for_install) const
// If the rpath will be replaced at install time, prepare space.
if (!for_install && this->RuntimeUseChrpath) {
if (!rpath.empty()) {
- // Add one trailing separator so the linker does not re-use the
+ // Add one trailing separator so the linker does not reuse the
// rpath .dynstr entry for a symbol name that happens to match
// the end of the rpath string.
rpath += this->GetRuntimeSep();
diff --git a/Source/cmExtraCodeLiteGenerator.cxx b/Source/cmExtraCodeLiteGenerator.cxx
index 7538a7f..5d2b045 100644
--- a/Source/cmExtraCodeLiteGenerator.cxx
+++ b/Source/cmExtraCodeLiteGenerator.cxx
@@ -59,7 +59,7 @@ void cmExtraCodeLiteGenerator::Generate()
this->GlobalGenerator->GetProjectMap();
// loop projects and locate the root project.
- // and extract the information for creating the worspace
+ // and extract the information for creating the workspace
// root makefile
for (auto const& it : projectMap) {
cmLocalGenerator* lg = it.second[0];
diff --git a/Source/cmFileTimes.cxx b/Source/cmFileTimes.cxx
index bd896f5..0aaab1d 100644
--- a/Source/cmFileTimes.cxx
+++ b/Source/cmFileTimes.cxx
@@ -70,7 +70,7 @@ bool cmFileTimes::Load(std::string const& fileName)
{
std::unique_ptr<Times> ptr;
if (this->IsValid()) {
- // Invalidate this and re-use times
+ // Invalidate this and reuse times
ptr.swap(this->times);
} else {
ptr = cm::make_unique<Times>();
diff --git a/Source/cmGeneratorTarget.cxx b/Source/cmGeneratorTarget.cxx
index f224ec1..930922c 100644
--- a/Source/cmGeneratorTarget.cxx
+++ b/Source/cmGeneratorTarget.cxx
@@ -6946,7 +6946,7 @@ cmLinkInterface const* cmGeneratorTarget::GetLinkInterface(
cmHeadToLinkInterfaceMap& hm = this->GetHeadToLinkInterfaceMap(config);
// If the link interface does not depend on the head target
- // then re-use the one from the head we computed first.
+ // then reuse the one from the head we computed first.
if (!hm.empty() && !hm.begin()->second.HadHeadSensitiveCondition) {
head = hm.begin()->first;
}
@@ -7074,7 +7074,7 @@ const cmLinkInterfaceLibraries* cmGeneratorTarget::GetLinkInterfaceLibraries(
: this->GetHeadToLinkInterfaceMap(config));
// If the link interface does not depend on the head target
- // then re-use the one from the head we computed first.
+ // then reuse the one from the head we computed first.
if (!hm.empty() && !hm.begin()->second.HadHeadSensitiveCondition) {
head = hm.begin()->first;
}
@@ -7596,7 +7596,7 @@ const cmLinkInterface* cmGeneratorTarget::GetImportLinkInterface(
: this->GetHeadToLinkInterfaceMap(config));
// If the link interface does not depend on the head target
- // then re-use the one from the head we computed first.
+ // then reuse the one from the head we computed first.
if (!hm.empty() && !hm.begin()->second.HadHeadSensitiveCondition) {
headTarget = hm.begin()->first;
}
@@ -8156,7 +8156,7 @@ cmGeneratorTarget::GetLinkImplementationLibrariesInternal(
: this->GetHeadToLinkImplementationMap(config));
// If the link implementation does not depend on the head target
- // then re-use the one from the head we computed first.
+ // then reuse the one from the head we computed first.
if (!hm.empty() && !hm.begin()->second.HadHeadSensitiveCondition) {
head = hm.begin()->first;
}
diff --git a/Source/cmGlobalGenerator.cxx b/Source/cmGlobalGenerator.cxx
index 933e754..bec389f 100644
--- a/Source/cmGlobalGenerator.cxx
+++ b/Source/cmGlobalGenerator.cxx
@@ -1865,7 +1865,7 @@ bool cmGlobalGenerator::AddAutomaticSources()
}
lg->AddUnityBuild(gt.get());
lg->AddISPCDependencies(gt.get());
- // Targets that re-use a PCH are handled below.
+ // Targets that reuse a PCH are handled below.
if (!gt->GetProperty("PRECOMPILE_HEADERS_REUSE_FROM")) {
lg->AddPchDependencies(gt.get());
}
@@ -1877,7 +1877,7 @@ bool cmGlobalGenerator::AddAutomaticSources()
if (!gt->CanCompileSources()) {
continue;
}
- // Handle targets that re-use a PCH from an above-handled target.
+ // Handle targets that reuse a PCH from an above-handled target.
if (gt->GetProperty("PRECOMPILE_HEADERS_REUSE_FROM")) {
lg->AddPchDependencies(gt.get());
}
diff --git a/Source/cmMakefile.cxx b/Source/cmMakefile.cxx
index 80f8a77..4a190db 100644
--- a/Source/cmMakefile.cxx
+++ b/Source/cmMakefile.cxx
@@ -3721,7 +3721,7 @@ int cmMakefile::TryCompile(const std::string& srcdir,
// make sure the same generator is used
// use this program as the cmake to be run, it should not
- // be run that way but the cmake object requires a vailid path
+ // be run that way but the cmake object requires a valid path
cmake cm(cmake::RoleProject, cmState::Project,
cmState::ProjectKind::TryCompile);
auto gg = cm.CreateGlobalGenerator(this->GetGlobalGenerator()->GetName());
diff --git a/Tests/CPackComponentsDEB/RunCPackVerifyResult.cmake b/Tests/CPackComponentsDEB/RunCPackVerifyResult.cmake
index b61e62d..64a8885 100644
--- a/Tests/CPackComponentsDEB/RunCPackVerifyResult.cmake
+++ b/Tests/CPackComponentsDEB/RunCPackVerifyResult.cmake
@@ -1,4 +1,4 @@
-# prevent older policies from interfearing with this script
+# prevent older policies from interfering with this script
cmake_policy(PUSH)
cmake_policy(VERSION ${CMAKE_VERSION})
diff --git a/Tests/CPackComponentsForAll/RunCPackVerifyResult.cmake b/Tests/CPackComponentsForAll/RunCPackVerifyResult.cmake
index 260a0f8..07281ed 100644
--- a/Tests/CPackComponentsForAll/RunCPackVerifyResult.cmake
+++ b/Tests/CPackComponentsForAll/RunCPackVerifyResult.cmake
@@ -1,4 +1,4 @@
-# prevent older policies from interfearing with this script
+# prevent older policies from interfering with this script
cmake_policy(PUSH)
cmake_policy(VERSION ${CMAKE_VERSION})
diff --git a/Tests/CTestUpdateCVS.cmake.in b/Tests/CTestUpdateCVS.cmake.in
index 8e0b611..d3263c3 100644
--- a/Tests/CTestUpdateCVS.cmake.in
+++ b/Tests/CTestUpdateCVS.cmake.in
@@ -17,7 +17,7 @@ message("Using CVS tools:")
set(CVS "@CVS_EXECUTABLE@")
message(" cvs = ${CVS}")
-# Pre-pending :local: prevents cvs from trying to interpret Windows drive
+# Prepending :local: prevents cvs from trying to interpret Windows drive
# letters, like "C:", as host names.
set(REPO ":local:${TOP}/repo")
diff --git a/Tests/RunCMake/ctest_memcheck/testAddressSanitizer.cmake b/Tests/RunCMake/ctest_memcheck/testAddressSanitizer.cmake
index 6612375..c177447 100644
--- a/Tests/RunCMake/ctest_memcheck/testAddressSanitizer.cmake
+++ b/Tests/RunCMake/ctest_memcheck/testAddressSanitizer.cmake
@@ -12,7 +12,7 @@ endif()
# clear the log file
file(REMOVE "${LOG_FILE}.2343")
-# create an example error from address santizer
+# create an example error from address sanitizer
file(APPEND "${LOG_FILE}.2343"
"=================================================================
diff --git a/Tests/RunCMake/ctest_memcheck/testMemorySanitizer.cmake b/Tests/RunCMake/ctest_memcheck/testMemorySanitizer.cmake
index 4b5ef7e..9030009 100644
--- a/Tests/RunCMake/ctest_memcheck/testMemorySanitizer.cmake
+++ b/Tests/RunCMake/ctest_memcheck/testMemorySanitizer.cmake
@@ -12,7 +12,7 @@ endif()
# clear the log file
file(REMOVE "${LOG_FILE}.2343")
-# create an error of each type of thread santizer
+# create an error of each type of thread sanitizer
# these names come from tsan_report.cc in llvm
file(APPEND "${LOG_FILE}.2343"
diff --git a/Tests/RunCMake/ctest_memcheck/testThreadSanitizer.cmake b/Tests/RunCMake/ctest_memcheck/testThreadSanitizer.cmake
index 96251c3..29244b2 100644
--- a/Tests/RunCMake/ctest_memcheck/testThreadSanitizer.cmake
+++ b/Tests/RunCMake/ctest_memcheck/testThreadSanitizer.cmake
@@ -23,7 +23,7 @@ set(error_types
# clear the log file
file(REMOVE "${LOG_FILE}.2343")
-# create an error of each type of thread santizer
+# create an error of each type of thread sanitizer
# these names come from tsan_report.cc in llvm
foreach(error_type ${error_types} )
diff --git a/Tests/RunCMake/ctest_memcheck/testUndefinedBehaviorSanitizer.cmake b/Tests/RunCMake/ctest_memcheck/testUndefinedBehaviorSanitizer.cmake
index 7160280..77481b1 100644
--- a/Tests/RunCMake/ctest_memcheck/testUndefinedBehaviorSanitizer.cmake
+++ b/Tests/RunCMake/ctest_memcheck/testUndefinedBehaviorSanitizer.cmake
@@ -12,7 +12,7 @@ endif()
# clear the log file
file(REMOVE "${LOG_FILE}.2343")
-# create an error like undefined behavior santizer creates;
+# create an error like undefined behavior sanitizer creates;
# these names come from ubsan_diag.cc and ubsan_handlers.cc
# in llvm
diff --git a/Tests/UseSWIG/ModuleVersion2/CMakeLists.txt b/Tests/UseSWIG/ModuleVersion2/CMakeLists.txt
index 317ed47..ded6b23 100644
--- a/Tests/UseSWIG/ModuleVersion2/CMakeLists.txt
+++ b/Tests/UseSWIG/ModuleVersion2/CMakeLists.txt
@@ -39,7 +39,7 @@ if(CMake_TEST_FindPython2)
COMMAND "${CMAKE_COMMAND}" -E env "PYTHONPATH=$<TARGET_PROPERTY:example1,SWIG_SUPPORT_FILES_DIRECTORY>${PS}$<TARGET_FILE_DIR:example1>"
"${Python2_EXECUTABLE}" "${CMAKE_CURRENT_SOURCE_DIR}/../runme.py")
- # re-use sample interface file for another plugin
+ # reuse sample interface file for another plugin
swig_add_library(example2
LANGUAGE python
SOURCES ../example.i ../example.cxx)
@@ -73,7 +73,7 @@ if(CMake_TEST_FindPython3)
"${Python3_EXECUTABLE}" "${CMAKE_CURRENT_SOURCE_DIR}/../runme.py")
- # re-use sample interface file for another plugin
+ # reuse sample interface file for another plugin
swig_add_library(example4
LANGUAGE python
SOURCES ../example.i ../example.cxx)
diff --git a/Tests/UseSWIG/MultipleModules/CMakeLists.txt b/Tests/UseSWIG/MultipleModules/CMakeLists.txt
index 4380080..4db28d7 100644
--- a/Tests/UseSWIG/MultipleModules/CMakeLists.txt
+++ b/Tests/UseSWIG/MultipleModules/CMakeLists.txt
@@ -38,7 +38,7 @@ set_target_properties (example1 PROPERTIES
RUNTIME_OUTPUT_DIRECTORY "${CMAKE_CURRENT_BINARY_DIR}/Python")
target_link_libraries(example1 PRIVATE Python::Module)
-# re-use sample interface file for another plugin
+# reuse sample interface file for another plugin
set_property(SOURCE "../example.i" APPEND PROPERTY
GENERATED_INCLUDE_DIRECTORIES ${PERL_INCLUDE_PATH})
separate_arguments(c_flags UNIX_COMMAND "${PERL_EXTRA_C_FLAGS}")
diff --git a/Tests/UseSWIG/MultiplePython/CMakeLists.txt b/Tests/UseSWIG/MultiplePython/CMakeLists.txt
index cf6c80e..0cb6f19 100644
--- a/Tests/UseSWIG/MultiplePython/CMakeLists.txt
+++ b/Tests/UseSWIG/MultiplePython/CMakeLists.txt
@@ -36,7 +36,7 @@ set_target_properties (example1 PROPERTIES
RUNTIME_OUTPUT_DIRECTORY "${CMAKE_CURRENT_BINARY_DIR}/Python2")
target_link_libraries(example1 PRIVATE Python2::Module)
-# re-use sample interface file for another plugin
+# reuse sample interface file for another plugin
swig_add_library(example2
LANGUAGE python
OUTPUT_DIR "${CMAKE_CURRENT_BINARY_DIR}/Python3"
diff --git a/Source/cmComputeLinkDepends.cxx b/Source/cmComputeLinkDepends.cxx
index b5a8419..1b1f640 100644
--- a/Source/cmComputeLinkDepends.cxx
+++ b/Source/cmComputeLinkDepends.cxx
@@ -178,7 +178,7 @@ guaranteed to be acyclic.
The final list of items produced by this procedure consists of the
original user link line followed by minimal additional items needed to
satisfy dependencies. The final list is then filtered to de-duplicate
-items that we know the linker will re-use automatically (shared libs).
+items that we know the linker will reuse automatically (shared libs).
*/
@@ -382,7 +382,7 @@ cmComputeLinkDepends::Compute()
for (size_t i : cmReverseRange(this->FinalLinkOrder)) {
LinkEntry const& e = this->EntryList[i];
cmGeneratorTarget const* t = e.Target;
// Entries that we know the linker will re-use do not need to be repeated.
bool uniquify = t && t->GetType() == cmStateEnums::SHARED_LIBRARY;
if (!uniquify || emitted.insert(i).second) {
this->FinalLinkEntries.push_back(e);
@@ -382,7 +382,7 @@ cmComputeLinkDepends::Compute()
LinkEntry const& e = this->EntryList[i];
cmGeneratorTarget const* t = e.Target;
- // Entries that we know the linker will re-use do not need to be repeated.
+ // Entries that we know the linker will reuse do not need to be repeated.
bool uniquify = t && t->GetType() == cmStateEnums::SHARED_LIBRARY;
if (!uniquify || emitted.insert(i).second) {